@@ -118,6 +118,7 @@ class FieldTest(unittest.TestCase):
         model.BooleanField()
         model.PathField()
         model.FileTextField()
+        model.PackageUrlField()
 
     def test_empty_Field_has_no_content(self):
         field = model.Field()
@@ -167,6 +168,12 @@ class FieldTest(unittest.TestCase):
         expected = {'license.LICENSE': 'some license text'}
         assert expected == field.value
 
+    def test_PackageUrlField_is_valid_url(self):
+        assert model.PackageUrlField.is_valid_purl('pkg:pypi/saneyaml@0.1')
+
+    def test_PackageUrlField_is_valid_url_no_version(self):
+        assert model.PackageUrlField.is_valid_purl('pkg:pypi/saneyaml')
+
     def test_UrlField_is_valid_url(self):
         assert model.UrlField.is_valid_url('http://www.google.com')
 
@@ -678,6 +685,12 @@ this software and releases the component to Public Domain.
         result = model.get_field_names(abouts)
         assert expected == result
 
+    def test_comma_in_license(self):
+        test_file = get_test_loc('test_model/special_char/about.ABOUT')
+        a = model.About(test_file)
+        expected = Error(ERROR,  "The following character(s) cannot be in the license_key: [',']")
+        assert a.errors[0] == expected
+
     def test_load_dict_issue_433(self):
         package_data = {
             'about_resource': 'package1.zip',
